example

package
v0.2.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 4, 2026 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Overview

Package example provides a root command with simple and complex subcommands.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewRootCommand

func NewRootCommand() *cobra.Command

NewRootCommand creates a root command with simple and complex subcommands.

Types

This section is empty.

Directories

Path Synopsis
Package complex demonstrates advanced usage with CommonOptions.
Package complex demonstrates advanced usage with CommonOptions.
Package simple demonstrates basic usage of the cli package.
Package simple demonstrates basic usage of the cli package.

Jump to